@@ -22,7 +22,7 @@ use Carp;
 use Excel::Writer::XLSX::Chart;
 
 our @ISA     = qw(Excel::Writer::XLSX::Chart);
-our $VERSION = '0.82';
+our $VERSION = '0.83';
 
 
 ###############################################################################
@@ -115,6 +115,22 @@ sub _write_pie_chart {
 }
 
 
+###############################################################################
+#
+# combine()
+#
+# Override parent method to add a warning.
+#
+sub combine {
+
+    my $self  = shift;
+    my $chart = shift;
+
+    carp "Combined chart not currently supported for Pie charts";
+    return;
+}
+
+
 ##############################################################################
 #
 # _write_plot_area().
